@@ -11,20 +11,28 @@ Tiago Romagnani Silveira, 2017
 
 import os
 import random
-import qrcode
 import traceback
 from decimal import Decimal
+from functools import partial
+import sys
 
+import qrcode
 from PyQt5.QtPrintSupport import QPrinter
+from PyQt5.QtCore import Qt, QRectF, QRect, QSizeF, QUrl, QPoint, QSize
+from PyQt5.QtGui import (QPixmap, QImage, QBitmap, QPainter, QFontDatabase, QPen, QFont,
+                         QColor, QDesktopServices, qRgba, QPainterPath)
+from PyQt5.QtWidgets import (QGridLayout, QVBoxLayout, QHBoxLayout, QLabel,
+                             QPushButton, QLineEdit)
 
 from electrum.plugin import hook
 from electrum.i18n import _
-from electrum.util import make_dir, InvalidPassword, UserCancelled, bh2u, bfh
-from electrum.gui.qt.util import *
+from electrum.util import make_dir, InvalidPassword, UserCancelled
+from electrum.gui.qt.util import (read_QIcon, EnterButton, WWLabel, icon_path,
+                                  WindowModalDialog, Buttons, CloseButton, OkButton)
 from electrum.gui.qt.qrtextedit import ScanQRTextEdit
 from electrum.gui.qt.main_window import StatusBarButton
 
-from .revealer import RevealerPlugin, VersionedSeed
+from .revealer import RevealerPlugin
 
 
 class Plugin(RevealerPlugin):
@@ -54,7 +62,7 @@ class Plugin(RevealerPlugin):
 
     @hook
     def create_status_bar(self, parent):
-        b = StatusBarButton(QIcon(':icons/revealer.png'), "Revealer "+_("secret backup utility"),
+        b = StatusBarButton(read_QIcon('revealer.png'), "Revealer "+_("Visual Cryptography Plugin"),
                             partial(self.setup_dialog, parent))
         parent.addPermanentWidget(b)
 
@@ -98,17 +106,17 @@ class Plugin(RevealerPlugin):
         vbox = QVBoxLayout()
         logo = QLabel()
         self.hbox.addWidget(logo)
-        logo.setPixmap(QPixmap(':icons/revealer.png'))
+        logo.setPixmap(QPixmap(icon_path('revealer.png')))
         logo.setAlignment(Qt.AlignLeft)
         self.hbox.addSpacing(16)
-        vbox.addWidget(WWLabel("<b>"+_("Revealer Secret Backup Plugin")+"</b><br>"
-                                    +_("To encrypt your backup, first we need to load some noise.")+"<br/>"))
+        vbox.addWidget(WWLabel("<b>"+_("Revealer Visual Cryptography Plugin")+"</b><br><br>"
+                                    +_("To encrypt a secret, first create or load noise.")+"<br/>"))
         vbox.addSpacing(7)
         bcreate = QPushButton(_("Create a new Revealer"))
         bcreate.setMaximumWidth(181)
         bcreate.setDefault(True)
         vbox.addWidget(bcreate, Qt.AlignCenter)
-        self.load_noise = ScanQRTextEdit()
+        self.load_noise = ScanQRTextEdit(config=self.config)
         self.load_noise.setTabChangesFocus(True)
         self.load_noise.textChanged.connect(self.on_edit)
         self.load_noise.setMaximumHeight(33)
@@ -121,15 +129,13 @@ class Plugin(RevealerPlugin):
         vbox.addLayout(Buttons(self.next_button))
         self.next_button.clicked.connect(self.d.close)
         self.next_button.clicked.connect(partial(self.cypherseed_dialog, window))
-        vbox.addWidget(
-            QLabel("<b>" + _("Warning") + "</b>: " + _("Each revealer should be used only once.")
-                   +"<br>"+_("more information at <a href=\"https://revealer.cc/faq\">https://revealer.cc/faq</a>")))
+
 
         def mk_digital():
             try:
                 self.make_digital(self.d)
             except Exception:
-                traceback.print_exc(file=sys.stdout)
+                self.logger.exception('')
             else:
                 self.cypherseed_dialog(window)
 
@@ -228,10 +234,10 @@ class Plugin(RevealerPlugin):
         self.vbox = QVBoxLayout()
         logo = QLabel()
         hbox.addWidget(logo)
-        logo.setPixmap(QPixmap(':icons/revealer.png'))
+        logo.setPixmap(QPixmap(icon_path('revealer.png')))
         logo.setAlignment(Qt.AlignLeft)
         hbox.addSpacing(16)
-        self.vbox.addWidget(WWLabel("<b>" + _("Revealer Secret Backup Plugin") + "</b><br>"
+        self.vbox.addWidget(WWLabel("<b>" + _("Revealer Visual Cryptography Plugin") + "</b><br><br>"
                                + _("Ready to encrypt for revealer {}")
                                     .format(self.versioned_seed.version+'_'+self.versioned_seed.checksum)))
         self.vbox.addSpacing(11)
@@ -245,7 +251,7 @@ class Plugin(RevealerPlugin):
         self.vbox.addWidget(cprint)
         self.vbox.addSpacing(1)
         self.vbox.addWidget(WWLabel("<b>"+_("OR")+"</b> "+_("type a custom alphanumerical secret below:")))
-        self.text = ScanQRTextEdit()
+        self.text = ScanQRTextEdit(config=self.config)
         self.text.setTabChangesFocus(True)
         self.text.setMaximumHeight(70)
         self.text.textChanged.connect(self.customtxt_limits)
@@ -264,6 +270,8 @@ class Plugin(RevealerPlugin):
         self.ctext.setEnabled(False)
         self.vbox.addSpacing(11)
         self.vbox.addLayout(Buttons(CloseButton(d)))
+        self.vbox.addWidget(
+            QLabel("<br>"+"<b>" + _("Warning ") + "</b>: " + _("each Revealer is a one-time-pad, use it for a single secret.")))
         return bool(d.exec_())
 
     def update_wallet_name(self, name):
@@ -291,7 +299,7 @@ class Plugin(RevealerPlugin):
         bitmap.fill(Qt.white)
         painter = QPainter()
         painter.begin(bitmap)
-        QFontDatabase.addApplicationFont(os.path.join(os.path.dirname(__file__), 'SourceSansPro-Bold.otf') )
+        QFontDatabase.addApplicationFont(os.path.join(os.path.dirname(__file__), 'SourceSansPro-Bold.otf'))
         if len(txt) < 102 :
             fontsize = 15
             linespace = 15
@@ -317,12 +325,12 @@ class Plugin(RevealerPlugin):
             while len(' '.join(map(str, temp_seed))) > max_letters:
                nwords = nwords - 1
                temp_seed = seed_array[:nwords]
-            painter.drawText(QRect(0, linespace*n , self.SIZE[0], self.SIZE[1]), Qt.AlignHCenter, ' '.join(map(str, temp_seed)))
+            painter.drawText(QRect(0, linespace*n, self.SIZE[0], self.SIZE[1]), Qt.AlignHCenter, ' '.join(map(str, temp_seed)))
             del seed_array[:nwords]
 
         painter.end()
         img = bitmap.toImage()
-        if (self.rawnoise == False):
+        if not self.rawnoise:
             self.make_rawnoise()
 
         self.make_cypherseed(img, self.rawnoise, False, is_seed)
@@ -362,7 +370,6 @@ class Plugin(RevealerPlugin):
         self.filename_prefix = 'revealer_'
         revealer.save(self.get_path_to_revealer_file('.png'))
         self.toPdf(QImage(revealer))
-        QDesktopServices.openUrl(QUrl.fromLocalFile(self.get_path_to_revealer_file('.pdf')))
 
     def make_cypherseed(self, img, rawnoise, calibration=False, is_seed = True):
         img = img.convertToFormat(QImage.Format_Mono)
@@ -388,7 +395,6 @@ class Plugin(RevealerPlugin):
 
         if not calibration:
             self.toPdf(QImage(cypherseed))
-            QDesktopServices.openUrl(QUrl.fromLocalFile(self.get_path_to_revealer_file('.pdf')))
             cypherseed.save(self.get_path_to_revealer_file('.png'))
             self.bcrypt(self.c_dialog)
         return cypherseed
@@ -455,7 +461,7 @@ class Plugin(RevealerPlugin):
         painter.end()
 
     def pixelcode_2x2(self, img):
-        result = QImage(img.width()*2, img.height()*2, QImage.Format_ARGB32 )
+        result = QImage(img.width()*2, img.height()*2, QImage.Format_ARGB32)
         white = qRgba(255,255,255,0)
         black = qRgba(0,0,0,255)
 
@@ -549,7 +555,7 @@ class Plugin(RevealerPlugin):
                 painter.drawLine(base_img.width()-(dist_h), 0,  base_img.width()-(dist_h), base_img.height())
 
                 painter.drawImage(((total_distance_h))+11, ((total_distance_h))+11,
-                                  QImage(':icons/electrumb.png').scaledToWidth(2.1*(total_distance_h), Qt.SmoothTransformation))
+                                  QImage(icon_path('electrumb.png')).scaledToWidth(2.1*(total_distance_h), Qt.SmoothTransformation))
 
                 painter.setPen(QPen(Qt.white, border_thick*8))
                 painter.drawLine(base_img.width()-((total_distance_h))-(border_thick*8)/2-(border_thick/2)-2,
@@ -575,7 +581,7 @@ class Plugin(RevealerPlugin):
                 painter.drawLine(dist_h, 0,  dist_h, base_img.height())
                 painter.drawLine(0, base_img.height()-dist_v, base_img.width(), base_img.height()-(dist_v))
                 painter.drawLine(base_img.width()-(dist_h), 0,  base_img.width()-(dist_h), base_img.height())
-                logo = QImage(':icons/revealer_c.png').scaledToWidth(1.3*(total_distance_h))
+                logo = QImage(icon_path('revealer_c.png')).scaledToWidth(1.3*(total_distance_h))
                 painter.drawImage((total_distance_h)+ (border_thick), ((total_distance_h))+ (border_thick), logo, Qt.SmoothTransformation)
 
                 #frame around logo
@@ -617,7 +623,7 @@ class Plugin(RevealerPlugin):
                                      + self.versioned_seed.checksum)
                 target = QRectF(base_img.width()-65-qr_size,
                                 base_img.height()-65-qr_size,
-                                qr_size, qr_size )
+                                qr_size, qr_size)
                 painter.drawImage(target, qr_qt)
                 painter.setPen(QPen(Qt.black, 4))
                 painter.drawLine(base_img.width()-65-qr_size,
